@@ -160,6 +160,7 @@ namespace lsp
                 nCurrRow            = meta->start;
                 nCols               = port_list_size(meta->members);
                 nRows               = list_size(meta->items);
+                nSID                = 0;
             }
 
             virtual ~VSTPortGroup()
@@ -167,6 +168,7 @@ namespace lsp
                 nCurrRow            = 0;
                 nCols               = 0;
                 nRows               = 0;
+                nSID                = 0;
             }
 
         public:
@@ -477,6 +479,33 @@ namespace lsp
             }
     };
 
+    class VSTStreamPort: public VSTPort
+    {
+        private:
+            stream_t       *pStream;
+
+        public:
+            explicit VSTStreamPort(const port_t *meta, AEffect *effect, audioMasterCallback callback) : VSTPort(meta, effect, callback)
+            {
+                pStream     = stream_t::create(pMetadata->min, pMetadata->max, pMetadata->start);
+            }
+
+            virtual ~VSTStreamPort()
+            {
+                if (pStream != NULL)
+                {
+                    stream_t::destroy(pStream);
+                    pStream     = NULL;
+                }
+            }
+
+        public:
+            virtual void *getBuffer()
+            {
+                return pStream;
+            }
+    };
+
     class VSTFrameBufferPort: public VSTPort
     {
         private:
