@@ -58,6 +58,11 @@ namespace lsp
         static const float  BTH_DFL                 = GAIN_AMP_M_72_DB;
         static const float  BTH_STEP                = 0.05f;
 
+        static const float  BSA_MIN                 = GAIN_AMP_0_DB;
+        static const float  BSA_MAX                 = GAIN_AMP_P_72_DB;
+        static const float  BSA_DFL                 = GAIN_AMP_P_6_DB;
+        static const float  BSA_STEP                = 0.05f;
+
         static const float  MAKEUP_MIN              = GAIN_AMP_M_60_DB;
         static const float  MAKEUP_MAX              = GAIN_AMP_P_60_DB;
         static const float  MAKEUP_DFL              = GAIN_AMP_0_DB;
@@ -133,6 +138,7 @@ namespace lsp
         {
             CM_DOWNWARD,
             CM_UPWARD,
+            CM_BOOSTING,
 
             CM_DEFAULT              = CM_DOWNWARD
         };
