@@ -23,7 +23,9 @@
 #define METADATA_METADATA_H_
 
 #include <core/types.h>
+#include <core/sugar.h>
 
+#define LSP_SITE_URL                                    "https://lsp-plug.in/"
 #define LSP_BASE_URI                                    "http://lsp-plug.in/"
 #define LSP_ACRONYM                                     "LSP"
 #define LSP_PREFIX                                      "lsp"
@@ -41,8 +43,8 @@
 #define LSP_PLUGIN_URI(format, plugin)                  LSP_BASE_URI "plugins/" #format "/" #plugin
 #define LSP_PLUGIN_UI_URI(format, plugin)               LSP_UI_URI(format) #plugin
 #define LSP_LADSPA_BASE                                 0x4C5350
-#define LSP_DONATION_URI1                               "https://salt.bountysource.com/teams/" LSP_ARTIFACT_ID
-#define LSP_DONATION_URI2                               "https://liberapay.com/sadko4u/donate"
+#define LSP_DONATION_URL1                               "https://salt.bountysource.com/teams/" LSP_ARTIFACT_ID
+#define LSP_DONATION_URL2                               "https://liberapay.com/sadko4u/donate"
 #define LSP_PLUGINS_MAILBOX                             "lsp.plugin@gmail.com"
 #define LSP_DOWNLOAD_URI                                LSP_BASE_URI "?page=download"
 
@@ -165,7 +167,8 @@ namespace lsp
         R_MIDI,                 // MIDI events
         R_PORT_SET,             // Set of ports
         R_OSC,                  // OSC events
-        R_BYPASS                // Bypass
+        R_BYPASS,               // Bypass
+        R_STREAM                // Stream
     };
 
     enum flags_t
