@@ -8,7 +8,7 @@ compensate time spent for development.</p>
 
 <p>Binary distributions of the software are completely free but the source code for each plugin
 will be published under the free license only after the donation goal is reached. Detailed
-information is available at official site: <a href="http://lsp-plug.in/">http://lsp-plug.in/</a></p>
+information is available at official site: <a href="https://lsp-plug.in/">https://lsp-plug.in/</a></p>
 
 <p>Below the text of license used by <b>LSP Plugins</b> is present.</p>
 
