@@ -67,6 +67,7 @@ namespace lsp
     {
         { "Downward",   "compressor.downward" },
         { "Upward",     "compressor.upward" },
+        { "Boosting",   "compressor.boosting" },
         { NULL, NULL }
     };
 
@@ -74,6 +75,7 @@ namespace lsp
     {
         { "Down",       "compressor.down_ward" },
         { "Up",         "compressor.up_ward" },
+        { "Boot",       "compressor.boost_ing" },
         { NULL, NULL }
     };
 
@@ -131,6 +133,7 @@ namespace lsp
         LOG_CONTROL("cr" id, "Ratio" label, U_NONE, compressor_base_metadata::RATIO), \
         LOG_CONTROL("kn" id, "Knee" label, U_GAIN_AMP, compressor_base_metadata::KNEE), \
         EXT_LOG_CONTROL("bth" id, "Boost threshold" label, U_GAIN_AMP, compressor_base_metadata::BTH), \
+        EXT_LOG_CONTROL("bsa" id, "Boost signal amount" label, U_GAIN_AMP, compressor_base_metadata::BSA), \
         LOG_CONTROL("mk" id, "Makeup gain" label, U_GAIN_AMP, compressor_base_metadata::MAKEUP), \
         AMP_GAIN10("cdr" id, "Dry gain" label, GAIN_AMP_M_INF_DB),     \
         AMP_GAIN10("cwt" id, "Wet gain" label, GAIN_AMP_0_DB), \
@@ -145,7 +148,7 @@ namespace lsp
         METER_OUT_GAIN("slm" id, "Sidechain level meter" label, GAIN_AMP_P_24_DB), \
         METER_OUT_GAIN("clm" id, "Curve level meter" label, GAIN_AMP_P_24_DB), \
         METER_OUT_GAIN("elm" id, "Envelope level meter" label, GAIN_AMP_P_24_DB), \
-        METER_GAIN_DFL("rlm" id, "Reduction level meter" label, GAIN_AMP_P_48_DB, GAIN_AMP_0_DB)
+        METER_GAIN_DFL("rlm" id, "Reduction level meter" label, GAIN_AMP_P_72_DB, GAIN_AMP_0_DB)
 
     #define COMP_AUDIO_METER(id, label) \
         SWITCH("ilv" id, "Input level visibility" label, 1.0f), \
@@ -271,7 +274,7 @@ namespace lsp
         "compressor_mono",
         "bgsy",
         LSP_COMPRESSOR_BASE + 0,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         compressor_mono_ports,
@@ -289,7 +292,7 @@ namespace lsp
         "compressor_stereo",
         "unsc",
         LSP_COMPRESSOR_BASE + 1,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         compressor_stereo_ports,
@@ -307,7 +310,7 @@ namespace lsp
         "compressor_lr",
         "3nam",
         LSP_COMPRESSOR_BASE + 2,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         compressor_lr_ports,
@@ -325,7 +328,7 @@ namespace lsp
         "compressor_ms",
         "jjef",
         LSP_COMPRESSOR_BASE + 3,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         compressor_ms_ports,
@@ -344,7 +347,7 @@ namespace lsp
         "sc_compressor_mono",
         "lyjq",
         LSP_COMPRESSOR_BASE + 4,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         sc_compressor_mono_ports,
@@ -362,7 +365,7 @@ namespace lsp
         "sc_compressor_stereo",
         "5xzi",
         LSP_COMPRESSOR_BASE + 5,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         sc_compressor_stereo_ports,
@@ -380,7 +383,7 @@ namespace lsp
         "sc_compressor_lr",
         "fowg",
         LSP_COMPRESSOR_BASE + 6,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         sc_compressor_lr_ports,
@@ -398,7 +401,7 @@ namespace lsp
         "sc_compressor_ms",
         "ioqg",
         LSP_COMPRESSOR_BASE + 7,
-        LSP_VERSION(1, 0, 2),
+        LSP_VERSION(1, 0, 3),
         compressor_classes,
         E_INLINE_DISPLAY | E_DUMP_STATE,
         sc_compressor_ms_ports,
