@@ -426,6 +426,7 @@ namespace lsp
                 vChannels[i].sSCEq.destroy();
                 vChannels[i].sDelay.destroy();
                 vChannels[i].sCompDelay.destroy();
+                vChannels[i].sDryDelay.destroy();
             }
 
             delete [] vChannels;
@@ -460,6 +461,7 @@ namespace lsp
             c->sSCEq.set_sample_rate(sr);
             c->sDelay.init(max_delay);
             c->sCompDelay.init(max_delay);
+            c->sDryDelay.init(max_delay);
 
             for (size_t j=0; j<G_TOTAL; ++j)
                 c->sGraph[j].init(dyna_processor_base_metadata::TIME_MESH_SIZE, samples_per_dot);
@@ -573,6 +575,7 @@ namespace lsp
         {
             channel_t *c    = &vChannels[i];
             c->sCompDelay.set_delay(latency - c->sDelay.get_delay());
+            c->sDryDelay.set_delay(latency);
         }
 
         // Report latency
@@ -842,7 +845,9 @@ namespace lsp
             for (size_t i=0; i<channels; ++i)
             {
                 // Apply bypass
-                vChannels[i].sBypass.process(out_buf[i], in_buf[i], vChannels[i].vOut, to_process);
+                channel_t *c        = &vChannels[i];
+                c->sDryDelay.process(c->vIn, in_buf[i], to_process);            // Apply delay compensation
+                c->sBypass.process(out_buf[i], c->vIn, c->vOut, to_process);
 
 //                dump_buffer("out_buf", out_buf[i], samples);
 
