@@ -77,6 +77,7 @@ namespace lsp
 
         // Determine number of channels
         size_t channels     = (nMode == EQ_MONO) ? 1 : 2;
+        size_t max_latency  = 0;
 
         // Initialize analyzer
         if (!sAnalyzer.init(channels, graph_equalizer_base_metadata::FFT_RANK,
@@ -105,7 +106,7 @@ namespace lsp
             return;
 
         // Allocate buffer
-        size_t allocate     = (EQ_BUFFER_SIZE + (nBands + 1)*graph_equalizer_base_metadata::MESH_POINTS*2) * channels + graph_equalizer_base_metadata::MESH_POINTS;
+        size_t allocate     = (EQ_BUFFER_SIZE*2 + (nBands + 1)*graph_equalizer_base_metadata::MESH_POINTS*2) * channels + graph_equalizer_base_metadata::MESH_POINTS;
         float *abuf         = new float[allocate];
         if (abuf == NULL)
             return;
@@ -130,6 +131,8 @@ namespace lsp
 
             c->vIn              = NULL;
             c->vOut             = NULL;
+            c->vDryBuf          = abuf;
+            abuf               += EQ_BUFFER_SIZE;
             c->vBuffer          = abuf;
             abuf               += EQ_BUFFER_SIZE;
             c->vTrRe            = abuf;
@@ -148,6 +151,7 @@ namespace lsp
 
             // Initialize equalizer
             c->sEqualizer.init(nBands, graph_equalizer_base_metadata::FFT_RANK);
+            max_latency         = lsp_max(max_latency, c->sEqualizer.max_latency());
 
             for (size_t j=0; j<nBands; ++j)
             {
@@ -168,6 +172,14 @@ namespace lsp
             }
         }
 
+        // Initialize latency compensation delay
+        for (size_t i=0; i<channels; ++i)
+        {
+            eq_channel_t *c     = &vChannels[i];
+            if (!c->sDryDelay.init(max_latency))
+                return;
+        }
+
         // Bind ports
         size_t port_id          = 0;
 
@@ -532,6 +544,15 @@ namespace lsp
             sAnalyzer.reconfigure();
             sAnalyzer.get_frequencies(vFreqs, vIndexes, SPEC_FREQ_MIN, SPEC_FREQ_MAX, graph_equalizer_base_metadata::MESH_POINTS);
         }
+
+        // Update latency
+        size_t latency          = 0;
+        for (size_t i=0; i<channels; ++i)
+            latency                 = lsp_max(latency, vChannels[i].sEqualizer.get_latency());
+
+        for (size_t i=0; i<channels; ++i)
+            vChannels[i].sDryDelay.set_delay(latency);
+        set_latency(latency);
     }
 
     void graph_equalizer_base::update_sample_rate(long sr)
@@ -572,11 +593,19 @@ namespace lsp
 
         size_t fft_pos          = (ui_active()) ? nFftPosition : FFTP_NONE;
 
+        // Process samples
         while (samples > 0)
         {
             // Determine buffer size for processing
             size_t to_process   = (samples > EQ_BUFFER_SIZE) ? EQ_BUFFER_SIZE : samples;
 
+            // Store unprocessed data
+            for (size_t i=0; i<channels; ++i)
+            {
+                eq_channel_t *c     = &vChannels[i];
+                c->sDryDelay.process(c->vDryBuf, c->vIn, to_process);
+            }
+
             // Pre-process data
             if (nMode == EQ_MID_SIDE)
             {
@@ -658,7 +687,7 @@ namespace lsp
                     c->pOutMeter->setValue(dsp::abs_max(c->vBuffer, to_process));
 
                 // Process via bypass
-                c->sBypass.process(c->vOut, c->vIn, c->vBuffer, to_process);
+                c->sBypass.process(c->vOut, c->vDryBuf, c->vBuffer, to_process);
 
                 c->vIn             += to_process;
                 c->vOut            += to_process;
@@ -669,16 +698,10 @@ namespace lsp
         }
 
         // Output FFT curves for each channel and report latency
-        size_t latency          = 0;
-
         for (size_t i=0; i<channels; ++i)
         {
             eq_channel_t *c     = &vChannels[i];
 
-            // Calculate latency
-            if (latency < c->sEqualizer.get_latency())
-                latency         = c->sEqualizer.get_latency();
-
             // Output FFT curve
             mesh_t *mesh            = c->pFft->getBuffer<mesh_t>();
             if ((mesh != NULL) && (mesh->isEmpty()))
@@ -697,9 +720,6 @@ namespace lsp
             }
         }
 
-        // Update latency report
-        set_latency(latency);
-
         // For Mono and Stereo channels only the first channel should be processed
         if (nMode == EQ_STEREO)
             channels        = 1;
