@@ -125,6 +125,7 @@ namespace lsp
                     MBE_BUFFER_SIZE * sizeof(float) + // Global vSc[] for each channel
                     2 * filter_mesh_size + // vTr of each channel
                     filter_mesh_size + // vTrMem of each channel
+                    MBE_BUFFER_SIZE * sizeof(float) + // vInBuffer for each channel
                     MBE_BUFFER_SIZE * sizeof(float) + // vBuffer for each channel
                     MBE_BUFFER_SIZE * sizeof(float) + // vScBuffer for each channel
                     ((bSidechain) ? MBE_BUFFER_SIZE * sizeof(float) : 0) + // vExtScBuffer for each channel
@@ -191,6 +192,8 @@ namespace lsp
             c->vOut         = NULL;
             c->vScIn        = NULL;
 
+            c->vInBuffer    = reinterpret_cast<float *>(ptr);
+            ptr            += MBE_BUFFER_SIZE * sizeof(float);
             c->vBuffer      = reinterpret_cast<float *>(ptr);
             ptr            += MBE_BUFFER_SIZE * sizeof(float);
             c->vScBuffer    = reinterpret_cast<float *>(ptr);
@@ -1021,6 +1024,7 @@ namespace lsp
                 exp_band_t *b   = c->vPlan[j];
                 b->sDelay.set_delay(latency - b->nLookahead);
             }
+            c->sDelay.set_delay(latency);
         }
 
         nEnvBoost       = env_boost;
@@ -1220,7 +1224,8 @@ namespace lsp
                 for (size_t i=0; i<channels; ++i)
                 {
                     channel_t *c        = &vChannels[i];
-                    c->sDelay.process(c->vBuffer, c->vBuffer, to_process); // Apply delay to compensate lookahead feature
+                    c->sDelay.process(c->vInBuffer, c->vBuffer, to_process); // Apply delay to compensate lookahead feature
+                    dsp::copy(vBuffer, c->vInBuffer, to_process);
 
                     for (size_t j=0; j<c->nPlanSize; ++j)
                     {
@@ -1237,8 +1242,9 @@ namespace lsp
                     channel_t *c        = &vChannels[i];
 
                     // Originally, there is no signal
-                    c->sDelay.process(vBuffer, c->vBuffer, to_process); // Apply delay to compensate lookahead feature, store into vBuffer
-                    dsp::fill_zero(c->vBuffer, to_process); // Clear the channel buffer
+                    c->sDelay.process(c->vInBuffer, c->vBuffer, to_process); // Apply delay to compensate lookahead feature, store into vBuffer
+                    dsp::copy(vBuffer, c->vInBuffer, to_process);
+                    dsp::fill_zero(c->vBuffer, to_process);                 // Clear the channel buffer
 
                     for (size_t j=0; j<c->nPlanSize; ++j)
                     {
@@ -1266,7 +1272,10 @@ namespace lsp
 
             // Post-process data (if needed)
             if (nMode == MBEM_MS)
+            {
                 dsp::ms_to_lr(vChannels[0].vBuffer, vChannels[1].vBuffer, vChannels[0].vBuffer, vChannels[1].vBuffer, to_process);
+                dsp::ms_to_lr(vChannels[0].vInBuffer, vChannels[1].vInBuffer, vChannels[0].vInBuffer, vChannels[1].vInBuffer, to_process);
+            }
 
             // Final metering
             for (size_t i=0; i<channels; ++i)
@@ -1274,10 +1283,10 @@ namespace lsp
                 channel_t *c        = &vChannels[i];
 
                 // Apply dry/wet gain and bypass
-                dsp::mix2(c->vBuffer, c->vIn, fWetGain, fDryGain, to_process);
+                dsp::mix2(c->vBuffer, c->vInBuffer, fWetGain, fDryGain, to_process);
                 float level         = dsp::abs_max(c->vBuffer, to_process);
                 c->pOutLvl->setValue(level);
-                c->sBypass.process(c->vOut, c->vIn, c->vBuffer, to_process);
+                c->sBypass.process(c->vOut, c->vInBuffer, c->vBuffer, to_process);
 
                 // Update pointers
                 c->vIn             += to_process;
