@@ -28,14 +28,19 @@ namespace native
 {
     void lanczos_resample_2x2(float *dst, const float *src, size_t count);
     void lanczos_resample_2x3(float *dst, const float *src, size_t count);
+    void lanczos_resample_2x4(float *dst, const float *src, size_t count);
     void lanczos_resample_3x2(float *dst, const float *src, size_t count);
     void lanczos_resample_3x3(float *dst, const float *src, size_t count);
+    void lanczos_resample_3x4(float *dst, const float *src, size_t count);
     void lanczos_resample_4x2(float *dst, const float *src, size_t count);
     void lanczos_resample_4x3(float *dst, const float *src, size_t count);
+    void lanczos_resample_4x4(float *dst, const float *src, size_t count);
     void lanczos_resample_6x2(float *dst, const float *src, size_t count);
     void lanczos_resample_6x3(float *dst, const float *src, size_t count);
+    void lanczos_resample_6x4(float *dst, const float *src, size_t count);
     void lanczos_resample_8x2(float *dst, const float *src, size_t count);
     void lanczos_resample_8x3(float *dst, const float *src, size_t count);
+    void lanczos_resample_8x4(float *dst, const float *src, size_t count);
 }
 
 IF_ARCH_X86(
@@ -43,28 +48,38 @@ IF_ARCH_X86(
     {
         void lanczos_resample_2x2(float *dst, const float *src, size_t count);
         void lanczos_resample_2x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_2x4(float *dst, const float *src, size_t count);
         void lanczos_resample_3x2(float *dst, const float *src, size_t count);
         void lanczos_resample_3x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_3x4(float *dst, const float *src, size_t count);
         void lanczos_resample_4x2(float *dst, const float *src, size_t count);
         void lanczos_resample_4x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_4x4(float *dst, const float *src, size_t count);
         void lanczos_resample_6x2(float *dst, const float *src, size_t count);
         void lanczos_resample_6x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_6x4(float *dst, const float *src, size_t count);
         void lanczos_resample_8x2(float *dst, const float *src, size_t count);
         void lanczos_resample_8x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_8x4(float *dst, const float *src, size_t count);
     }
 
     namespace avx
     {
         void lanczos_resample_2x2(float *dst, const float *src, size_t count);
         void lanczos_resample_2x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_2x4(float *dst, const float *src, size_t count);
         void lanczos_resample_3x2(float *dst, const float *src, size_t count);
         void lanczos_resample_3x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_3x4(float *dst, const float *src, size_t count);
         void lanczos_resample_4x2(float *dst, const float *src, size_t count);
         void lanczos_resample_4x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_4x4(float *dst, const float *src, size_t count);
         void lanczos_resample_6x2(float *dst, const float *src, size_t count);
         void lanczos_resample_6x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_6x4(float *dst, const float *src, size_t count);
         void lanczos_resample_8x2(float *dst, const float *src, size_t count);
         void lanczos_resample_8x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_8x4(float *dst, const float *src, size_t count);
     }
 )
 
@@ -73,14 +88,19 @@ IF_ARCH_ARM(
     {
         void lanczos_resample_2x2(float *dst, const float *src, size_t count);
         void lanczos_resample_2x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_2x4(float *dst, const float *src, size_t count);
         void lanczos_resample_3x2(float *dst, const float *src, size_t count);
         void lanczos_resample_3x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_3x4(float *dst, const float *src, size_t count);
         void lanczos_resample_4x2(float *dst, const float *src, size_t count);
         void lanczos_resample_4x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_4x4(float *dst, const float *src, size_t count);
         void lanczos_resample_6x2(float *dst, const float *src, size_t count);
         void lanczos_resample_6x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_6x4(float *dst, const float *src, size_t count);
         void lanczos_resample_8x2(float *dst, const float *src, size_t count);
         void lanczos_resample_8x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_8x4(float *dst, const float *src, size_t count);
     }
 )
 
@@ -89,14 +109,19 @@ IF_ARCH_AARCH64(
     {
         void lanczos_resample_2x2(float *dst, const float *src, size_t count);
         void lanczos_resample_2x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_2x4(float *dst, const float *src, size_t count);
         void lanczos_resample_3x2(float *dst, const float *src, size_t count);
         void lanczos_resample_3x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_3x4(float *dst, const float *src, size_t count);
         void lanczos_resample_4x2(float *dst, const float *src, size_t count);
         void lanczos_resample_4x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_4x4(float *dst, const float *src, size_t count);
         void lanczos_resample_6x2(float *dst, const float *src, size_t count);
         void lanczos_resample_6x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_6x4(float *dst, const float *src, size_t count);
         void lanczos_resample_8x2(float *dst, const float *src, size_t count);
         void lanczos_resample_8x3(float *dst, const float *src, size_t count);
+        void lanczos_resample_8x4(float *dst, const float *src, size_t count);
     }
 )
 
@@ -146,6 +171,13 @@ PTEST_BEGIN("dsp.resampling", oversampling, 5, 1000)
         IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_2x3, 2));
         PTEST_SEPARATOR;
 
+        CALL(native::lanczos_resample_2x4, 2);
+        IF_ARCH_X86(CALL(sse::lanczos_resample_2x4, 2));
+        IF_ARCH_X86(CALL(avx::lanczos_resample_2x4, 2));
+        IF_ARCH_ARM(CALL(neon_d32::lanczos_resample_2x4, 2));
+        IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_2x4, 2));
+        PTEST_SEPARATOR;
+
         CALL(native::lanczos_resample_3x2, 3);
         IF_ARCH_X86(CALL(sse::lanczos_resample_3x2, 3));
         IF_ARCH_X86(CALL(avx::lanczos_resample_3x2, 3));
@@ -160,6 +192,13 @@ PTEST_BEGIN("dsp.resampling", oversampling, 5, 1000)
         IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_3x3, 3));
         PTEST_SEPARATOR;
 
+        CALL(native::lanczos_resample_3x4, 3);
+        IF_ARCH_X86(CALL(sse::lanczos_resample_3x4, 3));
+        IF_ARCH_X86(CALL(avx::lanczos_resample_3x4, 3));
+        IF_ARCH_ARM(CALL(neon_d32::lanczos_resample_3x4, 3));
+        IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_3x4, 3));
+        PTEST_SEPARATOR;
+
         CALL(native::lanczos_resample_4x2, 4);
         IF_ARCH_X86(CALL(sse::lanczos_resample_4x2, 4));
         IF_ARCH_X86(CALL(avx::lanczos_resample_4x2, 4));
@@ -174,6 +213,13 @@ PTEST_BEGIN("dsp.resampling", oversampling, 5, 1000)
         IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_4x3, 4));
         PTEST_SEPARATOR;
 
+        CALL(native::lanczos_resample_4x4, 4);
+        IF_ARCH_X86(CALL(sse::lanczos_resample_4x4, 4));
+        IF_ARCH_X86(CALL(avx::lanczos_resample_4x4, 4));
+        IF_ARCH_ARM(CALL(neon_d32::lanczos_resample_4x4, 4));
+        IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_4x4, 4));
+        PTEST_SEPARATOR;
+
         CALL(native::lanczos_resample_6x2, 6);
         IF_ARCH_X86(CALL(sse::lanczos_resample_6x2, 6));
         IF_ARCH_X86(CALL(avx::lanczos_resample_6x2, 6));
@@ -188,6 +234,13 @@ PTEST_BEGIN("dsp.resampling", oversampling, 5, 1000)
         IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_6x3, 6));
         PTEST_SEPARATOR;
 
+        CALL(native::lanczos_resample_6x4, 6);
+        IF_ARCH_X86(CALL(sse::lanczos_resample_6x4, 6));
+        IF_ARCH_X86(CALL(avx::lanczos_resample_6x4, 6));
+        IF_ARCH_ARM(CALL(neon_d32::lanczos_resample_6x4, 6));
+        IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_6x4, 6));
+        PTEST_SEPARATOR;
+
         CALL(native::lanczos_resample_8x2, 8);
         IF_ARCH_X86(CALL(sse::lanczos_resample_8x2, 8));
         IF_ARCH_X86(CALL(avx::lanczos_resample_8x2, 8));
@@ -202,6 +255,13 @@ PTEST_BEGIN("dsp.resampling", oversampling, 5, 1000)
         IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_8x3, 8));
         PTEST_SEPARATOR;
 
+        CALL(native::lanczos_resample_8x4, 8);
+        IF_ARCH_X86(CALL(sse::lanczos_resample_8x4, 8));
+        IF_ARCH_X86(CALL(avx::lanczos_resample_8x4, 8));
+        IF_ARCH_ARM(CALL(neon_d32::lanczos_resample_8x4, 8));
+        IF_ARCH_AARCH64(CALL(asimd::lanczos_resample_8x4, 8));
+        PTEST_SEPARATOR;
+
         delete [] out;
         delete [] in;
     }
