@@ -126,6 +126,7 @@ namespace lsp
             fValue          = 0.0f;
             bDetailed       = true;
             bSameLine       = false;
+            bReadOnly       = false;
             nUnits          = U_NONE - 1;
             nPrecision      = -1;
             nAtomID         = -1;
@@ -157,6 +158,13 @@ namespace lsp
                 nAtomID = -1;
             }
 
+            if (pPopup != NULL)
+            {
+                pPopup->destroy();
+                delete pPopup;
+                pPopup = NULL;
+            }
+
             pWidget = NULL;
         }
 
@@ -226,6 +234,9 @@ namespace lsp
                 case A_SAME_LINE:
                     PARSE_BOOL(value, bSameLine = __);
                     break;
+                case A_READ_ONLY:
+                    PARSE_BOOL(value, bReadOnly = __);
+                    break;
                 case A_PRECISION:
                     PARSE_INT(value, nPrecision = __);
                     break;
@@ -397,6 +408,15 @@ namespace lsp
         {
             if (pPort != NULL)
                 commit_value();
+
+            // Get label widget
+            LSPLabel *lbl = widget_cast<LSPLabel>(pWidget);
+            if (lbl != NULL)
+            {
+                lbl->set_min_width(nMinWidth);
+                lbl->set_min_height(nMinHeight);
+            }
+
             CtlWidget::end();
         }
 
@@ -451,7 +471,7 @@ namespace lsp
         {
             // Get control pointer
             CtlLabel *_this = static_cast<CtlLabel *>(ptr);
-            if ((_this == NULL) || (_this->enType != CTL_LABEL_VALUE))
+            if ((_this == NULL) || (_this->enType != CTL_LABEL_VALUE) || (_this->bReadOnly))
                 return STATUS_OK;
 
             // Get port metadata
