@@ -1,8 +1,22 @@
 /*
- * LSPGrid.cpp
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 20 июн. 2017 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 20 июн. 2017 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <ui/tk/tk.h>
@@ -601,9 +615,6 @@ namespace lsp
                     if ((w->nRows <= 0) || (w->nCols <= 0))
                         continue;
 
-                    if (w->pWidget == NULL)
-                        lsp_trace("break");
-
                     w->a.nLeft      = v->nOffset;
                     w->a.nTop       = h->nOffset;
                     w->a.nWidth     = estimate_size(vCols, j, w->nCols, &hs);
