@@ -1,8 +1,22 @@
 /*
- * LSPLoadFile.cpp
+ * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
+ *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
  *
- *  Created on: 07 мая 2019 г.
- *      Author: sadko
+ * This file is part of lsp-plugins
+ * Created on: 07 мая 2019 г.
+ *
+ * lsp-plugins is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * any later version.
+ *
+ * lsp-plugins is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with lsp-plugins. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <ui/tk/tk.h>
@@ -151,9 +165,15 @@ namespace lsp
             // Create dialog
             LSP_STATUS_ASSERT(sDialog.init());
             sDialog.set_mode(FDM_OPEN_FILE);
-            sDialog.set_title("Load from file");
-            sDialog.set_action_title("Open");
-            sDialog.filter()->add("*", "All files (*.*)", "");
+            sDialog.title()->set("titles.load_from_file");
+            sDialog.action_title()->set("actions.open");
+            {
+                LSPFileFilterItem ffi;
+                ffi.pattern()->set("*");
+                ffi.title()->set("files.all");
+                ffi.set_extension("");
+                sDialog.filter()->add(&ffi);
+            }
             sDialog.bind_action(slot_on_file_submit, self());
 
             sDialog.slots()->bind(LSPSLOT_HIDE, slot_on_dialog_close, self());
