@@ -36,10 +36,13 @@ namespace lsp
             nPoints     = 0;
             nXIndex     = -1;
             nYIndex     = -1;
+            nSIndex     = -1;
+            nStrobes    = 0;
+            bStrobe     = false;
             vBuffer     = NULL;
             nBufSize    = 0;
 
-            pClass          = &metadata;
+            pClass      = &metadata;
         }
 
         LSPMesh::~LSPMesh()
@@ -97,6 +100,31 @@ namespace lsp
             query_draw();
         }
 
+        void LSPMesh::set_s_index(ssize_t value)
+        {
+            if (nSIndex == value)
+                return;
+            nSIndex = value;
+            query_draw();
+        }
+
+        void LSPMesh::set_num_strobes(ssize_t value)
+        {
+            size_t num = lsp_max(0, value);
+            if (nStrobes == num)
+                return;
+            nStrobes = num;
+            query_draw();
+        }
+
+        void LSPMesh::set_strobes(bool set)
+        {
+            if (bStrobe == set)
+                return;
+            bStrobe = set;
+            query_draw();
+        }
+
         void LSPMesh::set_center_id(size_t value)
         {
             if (nCenter == value)
@@ -108,13 +136,15 @@ namespace lsp
         status_t LSPMesh::set_data(size_t dimensions, size_t points, const float **data)
         {
 //            lsp_trace("dimensions = %d, points=%d, data=%p", int(dimensions), int(points), data);
-            size_t k=0;
+            ssize_t k=0, i=0;
             if (nXIndex >= 0)
                 ++k;
             if (nYIndex >= 0)
                 ++k;
+            if (nSIndex >= 0)
+                ++k;
 
-            size_t n = (k > 0) ? k : dimensions;
+            ssize_t n       = (k > 0) ? k : dimensions;
 
             // Allocate data
             size_t vec_size = ALIGN_SIZE(points, DEFAULT_ALIGN);
@@ -161,14 +191,29 @@ namespace lsp
                     dst            += vec_size;
                 }
             }
-            else
+
+            // Strobe is used?
+            if (nSIndex >= 0)
+                --n;
+
+            // Copy all data
+            for (; i<n; ++i)
             {
-                // Copy all data
-                for (size_t i=0; i<n; ++i)
-                {
-                    dsp::copy(dst, data[i], points);
-                    dst            += vec_size;
-                }
+                // Skip matching items
+                if ((i == nXIndex) || (i == nYIndex) || (i == nSIndex))
+                    continue;
+                dsp::copy(dst, data[i], points);
+                dst            += vec_size;
+            }
+
+            // Copy strobe data as last in the list
+            if (nSIndex >= 0)
+            {
+                if (nSIndex < ssize_t(dimensions))
+                    dsp::copy(dst, data[nSIndex], points);
+                else
+                    dsp::fill_zero(dst, points);
+                dst            += vec_size;
             }
 
             // Store dimensions
@@ -179,6 +224,39 @@ namespace lsp
             return STATUS_OK;
         }
 
+        size_t LSPMesh::find_offset(size_t *found, const float *v, size_t count, size_t strobes)
+        {
+            size_t nf       = 0;    // No strobes found
+            while (count > 0)
+            {
+                float s         = v[--count];
+                if (s < 0.5f)
+                    continue;
+                if ((strobes--) <= 0)   // We found start point?
+                    break;
+                ++nf;                   // Remember that we found the strobe
+            }
+
+            if (found != NULL)
+                *found = nf;
+
+            return count;
+        }
+
+        size_t LSPMesh::get_length(const float *v, size_t off, size_t count)
+        {
+            size_t start = off;
+            while (true)
+            {
+                if ((++off) >= count)
+                    return count - start;
+                if (v[off] >= 0.5f)
+                    break;
+            }
+
+            return off - start;
+        }
+
         void LSPMesh::render(ISurface *s, bool force)
         {
             // Get graph
@@ -194,19 +272,20 @@ namespace lsp
             color.scale_lightness(brightness());
 
             // Determine number of dimensions
-            size_t basis    = cv->basis_axes();
-            size_t n_vecs   = (nDimensions > basis) ? basis : nDimensions;
+            ssize_t dimensions  = (bStrobe) ? nDimensions - 1 : nDimensions;
+            ssize_t basis       = cv->basis_axes();
+            ssize_t n_vecs      = (dimensions > basis) ? basis : dimensions;
             if (n_vecs <= 0)
-            {
-//                lsp_trace("n_vecs <= 0");
                 return;
-            }
 
             float cx = 0.0f, cy = 0.0f;
             cv->center(nCenter, &cx, &cy);
 
             // Ensure that we have enough buffer size
             size_t vec_size     = ALIGN_SIZE(nPoints, DEFAULT_ALIGN);
+            size_t found        = 0;
+            size_t strobes      = nStrobes;
+            size_t off          = (bStrobe) ? find_offset(&found, &vBuffer[dimensions*vec_size], nPoints, strobes) : 0;
 
             // Initialize dimensions as zeros
             float *x_vec        = &vBuffer[nDimensions * vec_size];
@@ -216,7 +295,7 @@ namespace lsp
 
             // Calculate dot coordinates
             const float *src = vBuffer;
-            for (size_t i=0; i<n_vecs; ++i)
+            for (ssize_t i=0; i<n_vecs; ++i)
             {
                 // Try to get new axis
                 LSPAxis *axis   = cv->basis_axis(i);
@@ -235,14 +314,50 @@ namespace lsp
                 src += vec_size;
             }
 
-            // Now we have dots in x_vec[] and y_vec[]
+            // Now we have dots in x_vec[] and y_vec[], draw them
             bool aa = s->set_antialiasing(bSmooth);
-            if (sColor.alpha() <= 0.0f)
-                s->wire_poly(x_vec, y_vec, nPoints, nWidth, color);
+
+            if (bStrobe)
+            {
+                const float *svec   = &vBuffer[dimensions*vec_size];
+
+                // Draw mesh using strobes
+                ssize_t op  = strobes - found + 1;      // Initial opacity coefficient
+                float kop   = 1.0f / (strobes + 1.0f);  // Opacity coefficient
+                Color line, wire;
+
+                while (off < nPoints)
+                {
+                    size_t length       = get_length(svec, off, nPoints);
+                    float ka            = (op++) * kop;
+
+                    line.copy(color);
+                    line.alpha(1.0f - (1.0f - line.alpha()) * ka);
+
+                    // Draw part of mesh
+                    if (sColor.alpha() <= 0.0f)
+                        s->wire_poly(&x_vec[off], &y_vec[off], length, nWidth, line);
+                    else
+                    {
+                        wire.copy(sColor, 0.0f);
+                        wire.alpha(1.0f - (1.0f - wire.alpha()) * ka);
+                        s->draw_poly(&x_vec[off], &y_vec[off], length, nWidth, color, wire);
+                    }
+
+                    // Update offset
+                    off                += length;
+                }
+            }
             else
             {
-                Color wire(sColor, 0.0f);
-                s->draw_poly(x_vec, y_vec, nPoints, nWidth, color, wire);
+                // Draw mesh as usual
+                if (sColor.alpha() <= 0.0f)
+                    s->wire_poly(x_vec, y_vec, nPoints, nWidth, color);
+                else
+                {
+                    Color wire(sColor, 0.0f);
+                    s->draw_poly(x_vec, y_vec, nPoints, nWidth, color, wire);
+                }
             }
             s->set_antialiasing(aa);
         }
